# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2017-06-12 12:08
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='SearchQuery',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('url', models.URLField(max_length=255, verbose_name='URL')),
                ('text', models.CharField(max_length=255, unique=True, verbose_name='Text')),
                ('result_count', models.IntegerField(verbose_name='Result count')),
            ],
            options={
                'verbose_name': 'Search query',
                'verbose_name_plural': 'Search queries',
            },
        ),
        migrations.CreateModel(
            name='SearchTag',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('text', models.CharField(max_length=255, unique=True, verbose_name='Text')),
            ],
            options={
                'verbose_name': 'Search tag',
                'verbose_name_plural': 'Search tags',
            },
        ),
        migrations.CreateModel(
            name='SearchTagGroup',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, unique=True, verbose_name='Group name')),
            ],
            options={
                'verbose_name': 'Search tag group',
                'verbose_name_plural': 'Search tag groups',
            },
        ),
        migrations.AddField(
            model_name='searchtag',
            name='group',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='model_search.SearchTagGroup', verbose_name='Group'),
        ),
    ]
