
{% load i18n %}


<div class="modal fade" id="review-modal" tabindex="-1" role="dialog">

    <form method="post" action="{% url 'reviews:api' %}" enctype="multipart/form-data">

        <div class="modal-dialog" role="document">

            <div class="modal-content">

                <div data-role="splash" style="
                        display: none;
                        position: absolute;
                        top: 0;
                        bottom: 0;
                        left: 0;
                        right: 0;
                        background-color:rgba(255,255,255, 0.5);
                        z-index: 5;
                        font-size: 60px;
                        text-align: center;
                        padding-top: 47%;">
                    <i class="fa fa-spinner fa-spin"></i>
                </div>

                <div class="modal-header">
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                    <h4 class="modal-title">
                        {% trans "New review" %}
                    </h4>
                </div>

                <div class="modal-body">
                    {% include "reviews/new_review_form.html" %}
                </div>

                <div class="modal-footer">
                    <button type="button" class="btn btn-default pull-left" data-dismiss="modal">
                        {% trans 'Cancel' %}
                    </button>
                    <button type="submit" class="btn btn-success">
                        {% trans 'Send review' %}
                    </button>
                </div>

            </div>

        </div>

    </form>

</div>
