
BOWER_APPS_MAP = {
    'jquery': [
        'jquery#3.5.1',
        'jquery-form#4.3.0'
    ],
    'bootstrap': 'bootstrap#3.3.7',
    'jasny': 'jasny-bootstrap#3.1.3',
    'fa': 'components-font-awesome#5.15.1',
    'fancybox2': 'fancybox#2.1.6',
    'fancybox': 'fancybox#3.5.7',
    'pgwslideshow': 'pgwslideshow#2.0.2',
    'owl': 'owl.carousel#2.3.4',
    'autocomplete': 'devbridge-autocomplete#1.4.11',
    'tagsinput': 'bootstrap-tagsinput#0.8.0',
    'qtip2': 'qtip2#2.2.1',
    'cookie': 'jquery.cookie#1.4.1',
    'chosen': 'chosen#1.8.7',
    'jquery-ui': 'jquery-ui#1.12.1',
    'treeview': 'bootstrap-treeview#1.2.0',
    'slick': 'slick-carousel#1.8.1'
}


APPS_CSS_MAP = {
    'bootstrap': 'bower_components/bootstrap/dist/css/bootstrap.css',
    'bootstrap-theme': (
        'bower_components/bootstrap/dist/css/bootstrap-theme.css'),
    'jasny': 'bower_components/jasny-bootstrap/dist/css/jasny-bootstrap.css',
    'fa': 'bower_components/components-font-awesome/css/all.css',
    'fancybox2': 'bower_components/fancybox/source/jquery.fancybox.css',
    'fancybox': 'bower_components/fancybox/dist/jquery.fancybox.css',
    'pgwslideshow': [
        'bower_components/pgwslideshow/pgwslideshow.css',
        'bower_components/pgwslideshow/pgwslideshow_light.css'
    ],
    'owl': 'bower_components/owl.carousel/dist/assets/owl.carousel.css',
    'basement': 'css/indents.css',
    'tagsinput': (
        'bower_components/bootstrap-tagsinput/dist/bootstrap-tagsinput.css'),
    'qtip2': 'bower_components/qtip2/basic/jquery.qtip.css',
    'chosen': 'bower_components/chosen/chosen.css',
    'treeview': (
        'bower_components/bootstrap-treeview/dist/bootstrap-treeview.min.css'),
    'jquery-ui': 'bower_components/jquery-ui/themes/ui-lightness/jquery-ui.css',
    'slick': [
        'bower_components/slick-carousel/slick/slick.css',
        'bower_components/slick-carousel/slick/slick-theme.css'
    ]
}


APPS_JS_MAP = {
    'jquery': [
        'bower_components/jquery/dist/jquery.js',
        'bower_components/jquery-form/dist/jquery.form.min.js',
        'jquery/jquery.ba-bbq.js',
        'jquery/ajax-csrf.js',
        'modal.js'
    ],
    'bootstrap': 'bower_components/bootstrap/dist/js/bootstrap.js',
    'jasny': 'bower_components/jasny-bootstrap/dist/js/jasny-bootstrap.js',
    'fancybox2': 'bower_components/fancybox/source/jquery.fancybox.js',
    'fancybox': 'bower_components/fancybox/dist/jquery.fancybox.js',
    'pgwslideshow': 'bower_components/pgwslideshow/pgwslideshow.js',
    'owl': 'bower_components/owl.carousel/dist/owl.carousel.js',
    'autocomplete': (
        'bower_components/devbridge-autocomplete/dist/jquery.autocomplete.js'),
    'tagsinput': (
        'bower_components/bootstrap-tagsinput/dist/bootstrap-tagsinput.js'),
    'qtip2': 'bower_components/qtip2/basic/jquery.qtip.js',
    'cookie': 'bower_components/jquery.cookie/jquery.cookie.js',
    'treeview': (
        'bower_components/bootstrap-treeview/dist/bootstrap-treeview.min.js'),
    'jquery-ui': 'bower_components/jquery-ui/jquery-ui.js',
    'slick': 'bower_components/slick-carousel/slick/slick.js'
}
