# Generated by Django 3.0.10 on 2020-11-19 05:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('seo', '0007_search_query'),
    ]

    operations = [
        migrations.AddField(
            model_name='pagemeta',
            name='breadcrumb_en',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Breadcrumb'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='breadcrumb_ru',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Breadcrumb'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='breadcrumb_uk',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Breadcrumb'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='description_en',
            field=models.CharField(blank=True, max_length=155, null=True, verbose_name='Description'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='description_ru',
            field=models.CharField(blank=True, max_length=155, null=True, verbose_name='Description'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='description_uk',
            field=models.CharField(blank=True, max_length=155, null=True, verbose_name='Description'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='header_en',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Header'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='header_ru',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Header'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='header_uk',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Header'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='keywords_en',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Keywords'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='keywords_ru',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Keywords'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='keywords_uk',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Keywords'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='title_en',
            field=models.CharField(max_length=68, null=True, verbose_name='Title'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='title_ru',
            field=models.CharField(max_length=68, null=True, verbose_name='Title'),
        ),
        migrations.AddField(
            model_name='pagemeta',
            name='title_uk',
            field=models.CharField(max_length=68, null=True, verbose_name='Title'),
        ),
    ]
