# Generated by Django 3.0.10 on 2020-11-19 04:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('seo', '0006_pagemeta_og_image'),
    ]

    operations = [
        migrations.CreateModel(
            name='SearchQuery',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('query', models.CharField(blank=True, max_length=255, verbose_name='Query')),
                ('result_count', models.IntegerField(verbose_name='Result count')),
                ('filter_options', models.TextField(blank=True, max_length=2000, verbose_name='Filter')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
            ],
            options={
                'verbose_name': 'Search query',
                'verbose_name_plural': 'Search queries',
            },
        ),
    ]
