
{% extends 'base.html' %}

{% load i18n %}


{% block meta_title %}
    {% trans 'Sitemap' %}
{% endblock %}


{% block breadcrumb_items %}
    <li>{% trans 'Sitemap' %}</li>
{% endblock %}


{% block content %}

    <div class="container">

        <h1>{% trans 'Sitemap' %}</h1>

        <style>
            #sitemap > li ul {
                padding-left: 20px;
            }
        </style>

        <ul id="sitemap">
            {% block items %}
            {% endblock %}
            <li>
                <a href="https://mp-team.in.ua/">
                    {% trans 'Site developers' %}
                </a>
            </li>
        </ul>
    </div>

{% endblock %}
